/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2009 Jaroslav Tulach
 */

package cz.xelfi.quoridor.webidor.resources;

import com.sun.jersey.api.container.httpserver.HttpServerFactory;
import com.sun.jersey.api.core.PackagesResourceConfig;
import com.sun.jersey.api.core.ResourceConfig;
import com.sun.jersey.spi.resource.Singleton;
import com.sun.net.httpserver.HttpServer;
import java.io.File;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import javax.ws.rs.Path;

/**
 *
 * @author Jaroslav Tulach <jtulach@netbeans.org>
 */
@Path("/")
@Singleton
public final class Quoridor {
    private final File path;
    private Games games;

    public Quoridor() {
        final String prop = System.getProperty("quoridor.dir"); // NOI18N
        if (prop == null) {
            throw new IllegalStateException("quoridor.dir property must be specified"); // NOI18N
        }
        path = new File(prop);
        path.mkdirs();
    }

    @Path("games")
    public Games getGames() {
        if (games == null) {
            games = new Games(new File(path, "games"));
        }
        return games;
    }

    //
    // start the server
    //

    public static void main(String[] args) throws IOException {

        final String baseUri = "http://localhost:9998/";
        final Map<String, String> initParams = new HashMap<String, String>();

        initParams.put("com.sun.jersey.config.property.packages",
                "cz.xelfi.quoridor.webidor.resources");

        System.out.println("Starting HttpServer...");
        ResourceConfig rc = new PackagesResourceConfig("cz.xelfi.quoridor.webidor");
        HttpServer threadSelector = HttpServerFactory.create(baseUri, rc);
        threadSelector.start();
        System.out.println(String.format(
                    "Jersey app started with WADL available at %sapplication.wadl\n" +
            "Try out %shelloworld\nHit enter to stop it...", baseUri, baseUri));
            System.in.read();
            threadSelector.stop(0);
            System.exit(0);
    }

}
